@@ -34,9 +34,9 @@ struct pi_header64
 
 typedef struct
 {
-    FILE *ifp;
-    FILE *dfp;
-    FILE *wfp;
+    void *ifp;
+    void *dfp;
+    void *wfp;
     uint64_t flags;
     uint64_t hwms[256];
     struct pi_header64 header;
@@ -72,14 +72,14 @@ PWOpen(prefix, mode)
     char iname[STRINGSIZE];
     char dname[STRINGSIZE];
     char wname[STRINGSIZE];
-    FILE *dfp;
-    FILE *ifp;
-    FILE *wfp;
+    void *dfp;
+    void *ifp;
+    void *wfp;
 
     if (pdesc.header.pih_magic == PIH_MAGIC)
     {
 	fprintf(stderr, "%s: another dictionary already open\n", prefix);
-	return ((PWDICT *) 0);
+	return NULL;
     }
 
     memset(&pdesc, '\0', sizeof(pdesc));
@@ -102,11 +102,11 @@ PWOpen(prefix, mode)
 			if (!(pdesc.dfp = gzopen(dname, mode)))
 			{
 				perror(dname);
-				return ((PWDICT *) 0);
+				return NULL;
 			}
 #else
 		perror(dname);
-		return ((PWDICT *) 0);
+		return NULL;
 #endif
 		}
 	}
@@ -117,20 +117,20 @@ PWOpen(prefix, mode)
 		if (!(pdesc.dfp = fopen(dname, mode)))
 		{
 			perror(dname);
-			return ((PWDICT *) 0);
+			return NULL;
 		}
 	}
 
     if (!(pdesc.ifp = fopen(iname, mode)))
     {
 #ifdef HAVE_ZLIB_H
-		if(pdesc.flags & PFOR_USEZLIB)
+		if (pdesc.flags & PFOR_USEZLIB)
 			gzclose(pdesc.dfp);
 		else
 #endif
 			fclose(pdesc.dfp);
 	perror(iname);
-	return ((PWDICT *) 0);
+	return NULL;
     }
 
     if ((pdesc.wfp = fopen(wname, mode)))
@@ -161,16 +161,16 @@ PWOpen(prefix, mode)
 	    pdesc.header.pih_magic = 0;
 	    fclose(ifp);
 #ifdef HAVE_ZLIB_H
-		if(pdesc.flags & PFOR_USEZLIB)
+		if (pdesc.flags & PFOR_USEZLIB)
 			gzclose(dfp);
 		else
 #endif
 			fclose(dfp);
-	    if(wfp)
+	    if (wfp)
 	    {
 		fclose(wfp);
 	    }
-	    return ((PWDICT *) 0);
+	    return NULL;
 	}
 
         if ((pdesc.header.pih_magic == 0) || (pdesc.header.pih_numwords == 0))
@@ -180,40 +180,40 @@ PWOpen(prefix, mode)
             if (!fread((char *) &pdesc64.header, sizeof(pdesc64.header), 1, ifp))
             {
                 fprintf(stderr, "%s: error reading header\n", prefix);
- 
+
                 pdesc.header.pih_magic = 0;
                 fclose(ifp);
 #ifdef HAVE_ZLIB_H
-				if(pdesc.flags & PFOR_USEZLIB)
+				if (pdesc.flags & PFOR_USEZLIB)
 					gzclose(dfp);
 				else
 #endif
 					fclose(dfp);
-		if(wfp)
+		if (wfp)
 		{
 			fclose(wfp);
 		}
-                return ((PWDICT *) 0);
+                return NULL;
             }
             if (pdesc64.header.pih_magic != PIH_MAGIC)
             {
                 /* nope, not "64-bit" after all */
                 fprintf(stderr, "%s: error reading header\n", prefix);
- 
+
                 pdesc.header.pih_magic = 0;
                 fclose(ifp);
 #ifdef HAVE_ZLIB_H
-				if(pdesc.flags & PFOR_USEZLIB)
+				if (pdesc.flags & PFOR_USEZLIB)
 					gzclose(dfp);
 				else
 #endif
 					fclose(dfp);
 
-		if(wfp)
+		if (wfp)
 		{
 			fclose(wfp);
 		}
-                return ((PWDICT *) 0);
+                return NULL;
             }
             pdesc.header.pih_magic = pdesc64.header.pih_magic;
             pdesc.header.pih_numwords = pdesc64.header.pih_numwords;
@@ -229,36 +229,36 @@ PWOpen(prefix, mode)
 	    pdesc.header.pih_magic = 0;
 	    fclose(ifp);
 #ifdef HAVE_ZLIB_H
-		if(pdesc.flags & PFOR_USEZLIB)
+		if (pdesc.flags & PFOR_USEZLIB)
 			gzclose(dfp);
 		else
 #endif
 			fclose(dfp);
 
-	    if(wfp)
+	    if (wfp)
 	    {
 		fclose(wfp);
 	    }
-	    return ((PWDICT *) 0);
+	    return NULL;
 	}
 
         if (pdesc.header.pih_numwords < 1)
         {
             fprintf(stderr, "%s: invalid word count\n", prefix);
- 
+
             pdesc.header.pih_magic = 0;
             fclose(ifp);
 #ifdef HAVE_ZLIB_H
-			if(pdesc.flags & PFOR_USEZLIB)
+			if (pdesc.flags & PFOR_USEZLIB)
 				gzclose(dfp);
 			else
 #endif
 				fclose(dfp);
-	    if(wfp)
+	    if (wfp)
 	    {
 		fclose(wfp);
 	    }
-            return ((PWDICT *) 0);
+            return NULL;
         }
 
 	if (pdesc.header.pih_blocklen != NUMWORDS)
@@ -268,16 +268,16 @@ PWOpen(prefix, mode)
 	    pdesc.header.pih_magic = 0;
 	    fclose(ifp);
 #ifdef HAVE_ZLIB_H
-		if(pdesc.flags & PFOR_USEZLIB)
+		if (pdesc.flags & PFOR_USEZLIB)
 			gzclose(dfp);
 		else
 #endif
 			fclose(dfp);
-		if(wfp)
+		if (wfp)
 	    {
 		fclose(wfp);
 	    }
-	    return ((PWDICT *) 0);
+	    return NULL;
 	}
 
 	if (pdesc.flags & PFOR_USEHWMS)
@@ -294,7 +294,7 @@ PWOpen(prefix, mode)
                 {
                     pdesc.hwms[i] = pdesc64.hwms[i];
                 }
-            } 
+            }
             else if (fread(pdesc.hwms, 1, sizeof(pdesc.hwms), wfp) != sizeof(pdesc.hwms))
 	    {
 		pdesc.flags &= ~PFOR_USEHWMS;
@@ -324,7 +324,7 @@ PWClose(pwp)
     if (pwp->flags & PFOR_WRITE)
     {
 	pwp->flags |= PFOR_FLUSH;
-	PutPW(pwp, (char *) 0);	/* flush last index if necess */
+	PutPW(pwp, NULL);	/* flush last index if necess */
 
 	if (fseek(pwp->ifp, 0L, 0))
 	{
@@ -357,12 +357,12 @@ PWClose(pwp)
 
     fclose(pwp->ifp);
 #ifdef HAVE_ZLIB_H
-	if(pwp->flags & PFOR_USEZLIB)
+	if (pwp->flags & PFOR_USEZLIB)
 		gzclose(pwp->dfp);
 	else
 #endif
 		fclose(pwp->dfp);
-    if(pwp->wfp)
+    if (pwp->wfp)
     {
         fclose(pwp->wfp);
     }
@@ -465,26 +465,26 @@ GetPW(pwp, number)
        if (fseek(pwp->ifp, sizeof(struct pi_header64) + (thisblock * sizeof(uint64_t)), 0))
        {
            perror("(index fseek failed)");
-           return ((char *) 0);
+           return NULL;
        }
 
        if (!fread((char *) &datum64, sizeof(datum64), 1, pwp->ifp))
        {
            perror("(index fread failed)");
-           return ((char *) 0);
+           return NULL;
        }
        datum = datum64;
     } else {
        if (fseek(pwp->ifp, sizeof(struct pi_header) + (thisblock * sizeof(uint32_t)), 0))
        {
            perror("(index fseek failed)");
-           return ((char *) 0);
+           return NULL;
        }
 
        if (!fread((char *) &datum, sizeof(datum), 1, pwp->ifp))
        {
            perror("(index fread failed)");
-           return ((char *) 0);
+           return NULL;
        }
     }
 
@@ -493,18 +493,18 @@ GetPW(pwp, number)
 	if (pwp->flags & PFOR_USEZLIB)
 	{
 		r = gzseek(pwp->dfp, datum, 0);
-		if(r >= 0)
+		if (r >= 0)
 			r = 0;
 	}
 	else
 #endif
 		r = fseek(pwp->dfp, datum, 0);
 
-	
+
     if (r)
     {
 	perror("(data fseek failed)");
-	return ((char *) 0);
+	return NULL;
     }
 	r = 0;
 
@@ -513,19 +513,17 @@ GetPW(pwp, number)
 	if (pwp->flags & PFOR_USEZLIB)
 	{
 		r = gzread(pwp->dfp, buffer, sizeof(buffer));
-		if(r < 0)
+		if (r < 0)
 			r = 0;
 	}
 	else
 #endif
 		r = fread(buffer, 1, sizeof(buffer), pwp->dfp);
-		
-	
-	
+
     if (!r)
     {
 	perror("(data fread failed)");
-	return ((char *) 0);
+	return NULL;
     }
 
     prevblock = thisblock;
@@ -625,7 +623,7 @@ fprintf(stderr, "look for (%s)\n", string);
 
         if (middle == hwm)
         {
-#if DEBUG 
+#if DEBUG
 		fprintf(stderr, "at terminal subdivision, stopping search\n");
 #endif
 		break;
@@ -634,11 +632,11 @@ fprintf(stderr, "look for (%s)\n", string);
 	if (cmp < 0)
 	{
 	    hwm = middle;
-	} 
+	}
 	else if (cmp > 0)
 	{
 	    lwm = middle;
-	} 
+	}
     }
 
     return (PW_WORDS(pwp));
