@@ -1,7 +1,7 @@
 /*
- * This program is copyright Alec Muffett 1993, portions copyright other authors. 
+ * This program is copyright Alec Muffett 1993, portions copyright other authors.
  * The authors disclaim all responsibility or liability with respect to it's usage
- * or its effect upon hardware or computer systems. 
+ * or its effect upon hardware or computer systems.
  */
 
 #include <stdio.h>
@@ -27,7 +27,7 @@ main(argc, argv)
     {
 	file = DEFAULT_CRACKLIB_DICT;
     }
-    else 
+    else
     {
         file = argv[1];
     }
@@ -57,13 +57,13 @@ main(argc, argv)
 
 	if (!buffer[0])
 	{
-	    fprintf(stderr, "skipping line: %u\n", readed);
+	    fprintf(stderr, "skipping line: %lu\n", readed);
 	    continue;
 	}
 
 	if (PutPW(pwp, buffer))
 	{
-	    fprintf(stderr, "error: PutPW '%s' line %uy\n", buffer, readed);
+	    fprintf(stderr, "error: PutPW '%s' line %luy\n", buffer, readed);
 	}
 
 	wrote++;
@@ -71,7 +71,7 @@ main(argc, argv)
 
     PWClose(pwp);
 
-    printf("%u %u\n", readed, wrote);
+    printf("%lu %lu\n", readed, wrote);
 
     return (0);
 }
